@@ -73,7 +73,7 @@ _print_version_and_exit (const gchar *option_name,
                          gpointer data,
                          GError **error)
 {
-    g_print("%s %s\n", _("GNOME Font Viewer"), VERSION);
+    g_print("%s %s\n", _("GNOME Fonts"), VERSION);
     exit (EXIT_SUCCESS);
     return TRUE;
 }
@@ -88,6 +88,7 @@ static const GOptionEntry goption_options[] =
 G_DEFINE_TYPE (FontViewApplication, font_view_application, GTK_TYPE_APPLICATION);
 
 static void font_view_application_do_overview (FontViewApplication *self);
+static void ensure_window (FontViewApplication *self);
 
 #define VIEW_ITEM_WIDTH 140
 #define VIEW_ITEM_WRAP_WIDTH 128
@@ -737,6 +738,9 @@ query_info_ready_cb (GObject *object,
     GFileInfo *info;
     GError *error = NULL;
 
+    ensure_window (self);
+    g_application_release (G_APPLICATION (self));
+
     info = g_file_query_info_finish (G_FILE (object), res, &error);
     if (error != NULL) {
         font_view_application_do_overview (self);
@@ -756,6 +760,8 @@ font_view_application_open (GApplication *application,
                             const gchar *hint)
 {
     FontViewApplication *self = FONT_VIEW_APPLICATION (application);
+
+    g_application_hold (application);
     g_file_query_info_async (files[0], G_FILE_ATTRIBUTE_STANDARD_NAME,
                              G_FILE_QUERY_INFO_NONE,
                              G_PRIORITY_DEFAULT, NULL,
@@ -786,7 +792,7 @@ action_about (GSimpleAction *action,
     gtk_show_about_dialog (GTK_WINDOW (self->main_window),
                            "version", VERSION,
                            "authors", authors,
-                           "program-name", _("Font Viewer"),
+                           "program-name", _("Fonts"),
                            "comments", _("View fonts on your system"),
                            "logo-icon-name", "preferences-desktop-font",
                            "translator-credits", _("translator-credits"),
@@ -922,7 +928,6 @@ main (int argc,
 {
     GApplication *app;
     gint retval;
-    GError *error = NULL;
 
     bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
     bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
